0.2.1
-----

- The ``TemplateContent`` class now calls all context processors on
  instantiation. This ensures context processors are always called before
  response headers are sent.

0.2
---

Initial release

0.1
---

(unreleased version)
